function out = isDemandTable(demandTable, N)

    assert(~isempty(demandTable), '"demandTable" is empty');
    if (nargin < 2), N = max(demandTable(:)); end

    % Check whether a demand table is well-formed
    assert(numel(N) == 1 && isfinite(N) && N > 0 && N == floor(N), '"N" must be greater than 0');
    assert(ndims(demandTable) == 2 && ...
        size(demandTable, 2) == 2 && all(demandTable(:) == round(demandTable(:))) && ...
        all(isfinite(demandTable(:))) && min(demandTable(:)) > 0, ...
        '"demandTable" must be a non-negative non-zero integer Dx2 matrix');
    assert(max(demandTable(:)) <= N, ...
        sprintf('Node Ids in "demandTable" must be between 1 and %d', N));
    
    out = true;
    
end